<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>HiddenShortcutsDialog</name>
    <message>
        <location filename="../shortcuts.ui" line="14"/>
        <source>Hidden Shortcuts</source>
        <translation>Atalhos ocultos</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="20"/>
        <source>These hard coded shortcuts will be overridden if they are also assigned to other actions in Preferences → Shortcuts.</source>
        <translation>Estes atalhos codificados serão anulados se forem também atribuídos a outras ações em Preferências → Atalhos.</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="34"/>
        <source>Shortcut</source>
        <translation>Atalho</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="39"/>
        <source>Action</source>
        <translation>Ação</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="44"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="47"/>
        <source>Close window or exit fullscreen mode</source>
        <translation>Fechar janela ou sair em modo de ecrã inteiro</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="52"/>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="55"/>
        <location filename="../shortcuts.ui" line="63"/>
        <source>Next image</source>
        <translation>Imagem seguinte</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="60"/>
        <source>Space</source>
        <translation>Espaço</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="68"/>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="71"/>
        <source>Last image</source>
        <translation>Última imagem</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="76"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="79"/>
        <location filename="../shortcuts.ui" line="87"/>
        <source>Previous image</source>
        <translation>Imagem anterior</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="84"/>
        <source>Backspace</source>
        <translation>Backspace</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="92"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="95"/>
        <source>First image</source>
        <translation>Primeira imagem</translation>
    </message>
</context>
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../application.cpp" line="93"/>
        <source>Start in fullscreen (can be useful with tiling window managers)</source>
        <translation>Iniciar em ecrã inteiro (pode ser útil em gestores de janela de mosaico)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="101"/>
        <source>Take a screenshot (deprecated, please use screengrab instead)</source>
        <translation>Obter captura de ecrã (aplicação descontinuada, utilize o screengrab)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="110"/>
        <source>DIR</source>
        <translation>Diretório</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="110"/>
        <source>Take a screenshot and save it to the directory without showing the GUI (deprecated, please use screengrab instead)</source>
        <translation>Obter captura de ecrã e guardar para um diretório sem abrir a interface (aplicação descontinuada, utilize screengrab)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="116"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[Ficheiro1, Ficheiro2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgBBUpload</name>
    <message>
        <location filename="../upload/imgbbupload.cpp" line="44"/>
        <source>unknown error response</source>
        <translation>resposta de erro desconhecida</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../upload/imgurupload.cpp" line="47"/>
        <source>unknown error response</source>
        <translation>resposta de erro desconhecida</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>About</source>
        <translation>Acerca</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>A simple and fast image viewer</source>
        <translation>Um visualizador de imagens simples e rápido</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>Copyright (C) </source>
        <translation>Direitos de autor (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>LXQt Project</source>
        <translation>Projecto LXQt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <source>Development: </source>
        <translation>Desenvolvimento: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>Author: </source>
        <translation>Autor: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="515"/>
        <source>Open File</source>
        <translation>Abrir ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="516"/>
        <location filename="../mainwindow.cpp" line="551"/>
        <source>Image files (%1)</source>
        <translation>Ficheiros de imagem (%1)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="529"/>
        <source>Open directory</source>
        <translation>Abrir diretório</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>Save File</source>
        <translation>Guardar ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="846"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (A carregar...) - Visualizador de imagens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="852"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (Falha ao carregar...) - Visualizador de imagens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="858"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Visualizador de imagens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="904"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Visualizador de imagens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1302"/>
        <source>Thumbnails</source>
        <translation>Miniaturas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1397"/>
        <source>EXIF Data</source>
        <translation>Dados EXIF</translation>
    </message>
</context>
<context>
    <name>LxImage::MruMenu</name>
    <message>
        <location filename="../mrumenu.cpp" line="49"/>
        <source>&amp;Clear</source>
        <translation>&amp;Limpar</translation>
    </message>
</context>
<context>
    <name>LxImage::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="74"/>
        <source>Use a modifier key to clear a shortcut
in the editing mode.</source>
        <translation>Utilize uma tecla modificadora para
remover o atalho no modo de edição.</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="213"/>
        <source>Bottom</source>
        <translation>Baixo</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="214"/>
        <source>Top</source>
        <translation>Cima</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="215"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="341"/>
        <source>&lt;b&gt;Warning: Ambiguous shortcut detected!&lt;/b&gt;</source>
        <translation>&lt;b&gt;Aviso: detetado um atalho ambíguo!&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="358"/>
        <source>&lt;b&gt;Ambiguous shortcut not accepted.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Atalho ambíguo não aceite.&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>LxImage::SaveImageJob</name>
    <message>
        <location filename="../saveimagejob.cpp" line="54"/>
        <source>Cannot save with this image format!</source>
        <translation>Não foi possível guardar com este formato!</translation>
    </message>
</context>
<context>
    <name>LxImage::StatusBar</name>
    <message>
        <location filename="../statusbar.cpp" line="63"/>
        <source>Size:</source>
        <translation>Tamanho:</translation>
    </message>
    <message>
        <location filename="../statusbar.cpp" line="73"/>
        <source>Path:</source>
        <translation>Caminho:</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="50"/>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="51"/>
        <source>ImgBB</source>
        <translation>ImgBB</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="134"/>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="137"/>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="140"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="147"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Visualizador de imagens</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="204"/>
        <location filename="../mainwindow.ui" line="699"/>
        <source>Annotations Toolbar</source>
        <translation>Barra de ferramentas Anotação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>&amp;About</source>
        <translation>&amp;Acerca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="241"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>Save &amp;As</source>
        <translation>Gu&amp;ardar como</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="286"/>
        <source>&amp;Close</source>
        <translation>Fe&amp;char</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="298"/>
        <source>Zoom &amp;In</source>
        <translation>Ampl&amp;iar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <source>Zoom &amp;Out</source>
        <translation>Redu&amp;zir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="313"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="322"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>&amp;Copiar para área de transferência</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Next File</source>
        <translation>Ficheiro seguinte</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <location filename="../mainwindow.ui" line="349"/>
        <source>Previous File</source>
        <translation>Ficheiro anterior</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>Open &amp;With...</source>
        <translation>Abrir &amp;com...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&amp;Recently Opened Files</source>
        <translation>Ficheiros &amp;recentes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>Sorting</source>
        <translation>Ordenação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Hidden &amp;Shortcuts</source>
        <translation>&amp;Atalhos ocultos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="238"/>
        <source>&amp;Open…</source>
        <translation>&amp;Abrir…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="250"/>
        <source>&amp;Reload File</source>
        <translation>&amp;Recarregar ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="337"/>
        <source>PgDown</source>
        <translation>PageDown</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="352"/>
        <source>PgUp</source>
        <translation>PageUp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="364"/>
        <source>Original Size</source>
        <translation>Tamanho original</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="379"/>
        <source>&amp;Fit</source>
        <translation>Aj&amp;ustar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>&amp;Rodar à direita</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="391"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="400"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Rodar à &amp;esquerda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>P&amp;references</source>
        <translation>P&amp;referências</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="417"/>
        <source>&amp;Print</source>
        <translation>Im&amp;primir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="420"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="429"/>
        <source>First File</source>
        <translation>Primeiro ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="432"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="441"/>
        <source>Last File</source>
        <translation>Último ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="444"/>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="453"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nova janela</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="465"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Inverter na &amp;horizontal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="468"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="477"/>
        <source>Capture Screenshot</source>
        <translation>Captura de ecrã</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="485"/>
        <source>F&amp;ull Screen</source>
        <translation>E&amp;crã completo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>Flip &amp;Vertically</source>
        <translation>Inverter na &amp;vertical</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="500"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="509"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>Colar da área de trans&amp;ferência</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="521"/>
        <source>&amp;Slide Show</source>
        <translation>Apre&amp;sentação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>&amp;Delete</source>
        <translation>&amp;Eliminar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="533"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="541"/>
        <source>Show Thumbnails</source>
        <translation>Mostrar miniaturas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="544"/>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="553"/>
        <source>File Properties</source>
        <translation>Propriedades do ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="562"/>
        <source>Open &amp;Directory</source>
        <translation>Abrir &amp;diretório</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="565"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="574"/>
        <source>Upload</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="577"/>
        <source>Upload the image</source>
        <translation>Enviar imagem</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="580"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="588"/>
        <source>Show EXIF Data</source>
        <translation>Mostrar dados EXIF</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="600"/>
        <source>No Tool</source>
        <translation>Sem ferramenta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="603"/>
        <source>Deselect all drawing tools</source>
        <translation>Desmarcar todas as ferramentas de desenho</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="615"/>
        <source>Draw Arrow</source>
        <translation>Seta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="618"/>
        <source>Draw an arrow</source>
        <translation>Desenhar uma seta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="630"/>
        <source>Draw Rectangle</source>
        <translation>Retângulo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="633"/>
        <source>Draw a hollow rectangle</source>
        <translation>Desenhar um retângulo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="645"/>
        <source>Draw Circle</source>
        <translation>Círculo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="648"/>
        <source>Draw a hollow circle</source>
        <translation>Desenhar um círculo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="660"/>
        <source>Draw Number</source>
        <translation>Número</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="663"/>
        <source>Draw incrementing numbers</source>
        <translation>Desenhar números por incremento</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="671"/>
        <location filename="../mainwindow.ui" line="674"/>
        <source>Menubar</source>
        <translation>Barra de menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="677"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="685"/>
        <source>&amp;Main Toolbar</source>
        <translation>&amp;Barra de ferramentas principal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="688"/>
        <source>Main Toolbar</source>
        <translation>Barra de ferramentas principal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="696"/>
        <source>&amp;Annotations Toolbar</source>
        <translation>Barra de ferramentas &amp;Anotação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="707"/>
        <location filename="../mainwindow.ui" line="710"/>
        <source>Show Outline</source>
        <translation>Mostrar contorno</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="713"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="721"/>
        <source>Copy Pa&amp;th</source>
        <translation>Copiar camin&amp;ho</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="724"/>
        <source>Copy path</source>
        <translation>Copiar caminho</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="732"/>
        <location filename="../mainwindow.ui" line="735"/>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="738"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="747"/>
        <source>Resize</source>
        <translation>Redimensionar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="755"/>
        <source>&amp;By File Name</source>
        <translation>&amp;Por nome</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="758"/>
        <source>By File Name</source>
        <translation>Por nome</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="766"/>
        <source>By &amp;Modification Time</source>
        <translation>Por data de &amp;modificação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="769"/>
        <source>By Modification Time</source>
        <translation>Por data de modificação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="777"/>
        <source>By C&amp;reation Time</source>
        <translation>Por data de c&amp;riação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="780"/>
        <source>By Creation Time</source>
        <translation>Por data de criação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="788"/>
        <source>By File &amp;Size</source>
        <translation>Por &amp;tamanho</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="791"/>
        <source>By File Size</source>
        <translation>Por tamanho</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="799"/>
        <source>By File &amp;Type</source>
        <translation>Por &amp;tipo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="802"/>
        <source>By File Type</source>
        <translation>Por tipo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>&amp;File</source>
        <translation>&amp;Ficheiro</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="97"/>
        <source>&amp;Help</source>
        <translation>Aj&amp;uda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Go</source>
        <translation>Ir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="145"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="169"/>
        <source>Toolbar</source>
        <translation>Barra de ferramentas</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Preferências</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Tema de ícones:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="53"/>
        <source>Thumbnailer file size limit:</source>
        <translation>Limite do tamanho do ficheiro da miniatura:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="151"/>
        <source>Normal background color:</source>
        <translation>Cor de fundo normal:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="165"/>
        <source>Fullscreen background color:</source>
        <translation>Cor de fundo em ecrã inteiro:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="43"/>
        <source>Maximum number of recent files:</source>
        <translation>Número máximo de ficheiros recentes:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="228"/>
        <source>Slide show interval (seconds):</source>
        <translation>Intervalo entre imagens (segundos):</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="242"/>
        <source>Show image outline by default</source>
        <translation>Mostrar contorno da imagem, por definição</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="134"/>
        <source>Show annotations toolbar by default</source>
        <translation>Mostrar barra de anotações, por definição</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="249"/>
        <source>Fit images when navigating</source>
        <translation>Ajustar imagens ao navegar</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="60"/>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="76"/>
        <source>Thumbnail image dimensions:</source>
        <translation>Dimensões da imagem em miniatura:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="86"/>
        <source>Use system Trash (and do not prompt)</source>
        <translation>Utilizar o Lixo do sistema (e não perguntar)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="94"/>
        <source>Window</source>
        <translation>Janela</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="103"/>
        <source>Show thumbnails dock by default</source>
        <translation>Mostrar as miniaturas da doca por predefinição</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="113"/>
        <source>Show Exif data dock by default</source>
        <translation>Mostrar a doca de dados Exif por padrão</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="120"/>
        <source>Show menubar by default</source>
        <translation>Mostrar a barra de menu por padrão</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="127"/>
        <source>Show main toolbar by default</source>
        <translation>Mostrar a barra de ferramentas principal por padrão</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="142"/>
        <source>Image</source>
        <translation>Imagem</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="179"/>
        <location filename="../preferencesdialog.ui" line="190"/>
        <source>May work only with images which have valid color spaces.
Reload current image to see the effect.</source>
        <translation>Pode funcionar apenas com imagens que tenham espaços de cor válidos.
Recarregue a imagem atual para ver o efeito.</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="183"/>
        <source>Color space:</source>
        <translation>Espaço de cores:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="195"/>
        <source>None</source>
        <translation>Nenhuma</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="200"/>
        <source>sRGB (supported by most monitors)</source>
        <translation>sRGB (suportado pela maioria dos monitores)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="205"/>
        <source>Linear sRGB (linear gamma)</source>
        <translation>Linear sRGB (gama linear)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="210"/>
        <source>Adobe RGB</source>
        <translation>Adobe RGB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="215"/>
        <source>DisplayP3 (wide-gamut screens)</source>
        <translation>DisplayP3 (ecrãs de gama larga)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="220"/>
        <source>ProPhotoRgb</source>
        <translation>ProPhotoRgb</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="256"/>
        <source>Smooth images on zooming</source>
        <translation>Imagens suaves no zooming</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="264"/>
        <source>Shortcuts</source>
        <translation>Atalhos</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="283"/>
        <source>Action</source>
        <translation>Ação</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="288"/>
        <source>Shortcut</source>
        <translation>Atalho</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="296"/>
        <source>Default</source>
        <translation>Repor atalhos para os valores padrão</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Geral</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="996"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
<context>
    <name>ResizeImageDialog</name>
    <message>
        <location filename="../resizeimagedialog.ui" line="14"/>
        <source>Resize Image</source>
        <translation>Redimensionar imagem</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="26"/>
        <source>Width</source>
        <translation>Largura</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="33"/>
        <source>Height</source>
        <translation>Altura</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="40"/>
        <source>Current size:</source>
        <translation>Tamanho atual:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="80"/>
        <source>New size:</source>
        <translation>Novo tamanho:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="93"/>
        <location filename="../resizeimagedialog.ui" line="116"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="129"/>
        <location filename="../resizeimagedialog.ui" line="158"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="174"/>
        <source>Keep aspect ratio</source>
        <translation>Manter proporção</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Captura de ecrã</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Obter captura de ecrã</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Região</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Ecrã completo</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Apenas janela atual</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>Capturar uma área do ecrã</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Incluir cursor do rato</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="74"/>
        <source> sec</source>
        <translation> seg.</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Atraso:</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Incluir título e moldura da janela</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>Enviar</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.ui" line="39"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
</context>
</TS>
